pub fn add_to_linker<T>(linker: &mut Linker<T>) -> Result<()>where
T: WasiTlsView + 'static,Expand description
Add all interfaces from this module into the linker provided.
pub fn add_to_linker<T>(linker: &mut Linker<T>) -> Result<()>where
T: WasiTlsView + 'static,Add all interfaces from this module into the linker provided.