WasiTlsCtxBuilder

Struct WasiTlsCtxBuilder 

pub struct WasiTlsCtxBuilder { /* private fields */ }
Builder-style structure used to create a WasiTlsCtx.

Implementations

Source

impl WasiTlsCtxBuilder

pub fn new() -> Self

Creates a builder for a new context with default parameters set.

pub fn provider(self, provider: Box<dyn TlsProvider>) -> Self

Configure the TLS provider to use for this context.

By default, this is set to the DefaultProvider which is picked at compile time based on feature flags. If this crate is compiled with multiple TLS providers, this method can be used to specify the provider at runtime.

pub fn build(self) -> WasiTlsCtx

Uses the configured context so far to construct the final WasiTlsCtx.