pub struct UnsupportedProvider { /* private fields */ }Expand description
A pseudo TLS provider that returns an error for all operations. This is the default provider when no real TLS providers were enabled at compile time.