pub struct WasiTlsCtxBuilder { /* private fields */ }Expand description
Builder-style structure used to create a WasiTlsCtx.
Implementations
Sourceimpl WasiTlsCtxBuilder
impl WasiTlsCtxBuilder
Sourcepub fn provider(self, provider: Box<dyn TlsProvider>) -> Self
pub fn provider(self, provider: Box<dyn TlsProvider>) -> Self
Configure the TLS provider to use for this context.
By default, this is set to the DefaultProvider which is picked at
compile time based on feature flags. If this crate is compiled with
multiple TLS providers, this method can be used to specify the provider
at runtime.
Sourcepub fn build(self) -> WasiTlsCtx
pub fn build(self) -> WasiTlsCtx
Uses the configured context so far to construct the final WasiTlsCtx.